import {Component, OnDestroy, OnInit} from '@angular/core';
import {LecturerInfoService} from 'src/app/services/lecturer-info.service';
import {LecturerDataService} from 'src/app/services/lecturer-data.service';
import {Router} from '@angular/router';
import {MinutePaperDao} from 'src/app/dao/minute-paper.dao';
import {GridOptions} from 'ag-grid-community';
import {ViewSubmissionsButtonComponent} from 'src/app/GridComponents/ViewSubmissionsButton/view-submissions-button.component';
import {DeletePaperButtonComponent} from 'src/app/GridComponents/DeletePaperButton/delete-paper-button.component';

@Component({
  selector: 'app-lecturer-paperview',
  templateUrl: './lecturer-paper-view.component.html',
  styleUrls: ['./lecturer-paper-view.component.css']
})
export class LecturerPaperViewComponent implements OnInit, OnDestroy {

  public classCode: String;
  public lecturerId: String;
  public classPapers: any;
  public gridOptions: GridOptions;
  public columnDefs = [
    {headerName: 'Class Code', field: 'classCode', sortable: true, lockPosition: true},
    {headerName: 'Paper Name', field: 'name', sortable: true, lockPosition: true},
    {headerName: 'Topic', field: 'topic', sortable: true, lockPosition: true, filter: true},
    {headerName: 'Anonymous', field: 'anonymous', sortable: true, lockPosition: true},
    {headerName: 'Creation Date', field: 'creationDate', sortable: true, lockPosition: true},
    {headerName: 'View Submissions', field: '', cellRendererFramework: ViewSubmissionsButtonComponent, lockPosition: true},
    {headerName: 'Delete paper', field: '', cellRendererFramework: DeletePaperButtonComponent, lockPosition: true},
  ];

  constructor(private lecturerInfoService: LecturerInfoService,
              private lecturerDataService: LecturerDataService,
              private router: Router) {
  }

  ngOnInit(): void {
    this.classCode = this.lecturerDataService.classCode;
    this.lecturerId = sessionStorage.getItem('username');
    this.gridOptions = {
      context: {componentParent: this}
    };
    this.classPapers = this.lecturerInfoService.getClassPapers(this.lecturerId, this.classCode);
  }

  ngOnDestroy(): void {
    this.classPapers = [];
  }

  public goToSubmissionsView(paper: MinutePaperDao) {
    this.lecturerDataService.currentPaper = paper;
    this.router.navigate(['/submissions-view']);
    this.ngOnDestroy();
  }

  public removePaper(paper: MinutePaperDao, transaction: any) {
    const choice = confirm('Are you sure you want to delete this paper?\n' +
      'Deleting this paper will result in all responses being destroyed!');
    if (choice) {
      this.gridOptions.api.updateRowData(transaction);
      this.lecturerInfoService.deletePaper(paper.paperId).subscribe();
    }
  }
}
